#
# spec file for package python-webauthn
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-webauthn
Version:        2.5.0
Release:        1.1
Summary:        Pythonic WebAuthn
License:        BSD-3-Clause
URL:            https://github.com/duo-labs/py_webauthn
Source:         https://files.pythonhosted.org/packages/source/w/webauthn/webauthn-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module asn1crypto >= 1.4.0}
BuildRequires:  %{python_module cbor2 >= 5.4.6}
BuildRequires:  %{python_module cryptography >= 43.0.3}
BuildRequires:  %{python_module pyOpenSSL >= 23.3.0}
BuildRequires:  %{python_module pytest}
# /SECTION
BuildRequires:  fdupes
Requires:       python-asn1crypto >= 1.4.0
Requires:       python-cbor2 >= 5.4.6
Requires:       python-cryptography >= 43.0.3
Requires:       python-pyOpenSSL >= 23.3.0
BuildArch:      noarch
%python_subpackages

%description
Pythonic WebAuthn

%prep
%autosetup -p1 -n webauthn-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/webauthn
%{python_sitelib}/webauthn-%{version}.dist-info

%changelog
* Mon Jan 20 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.5.0
  * A new `require_user_presence` argument has been added to `verify_registration_response()`
    to enable verification of WebAuthn responses generated through use of conditional create
    where the `up` bit in `authData.flags` will be `False` (#236)
  * `verify_authentication_response()` has been updated to return `user_verified` as well to
    indicate whether or not the user performed user verification (#235)
  * Verification of `"android-key"` attestation statements has been modernized in light of
    Android's latest observable behavior (#240)
  * Verification of `"android-safetynet"` attestation statements now enforces the `"basicIntegrity"`
    flag instead of the `"ctsProfileMatch"` flag when determining device integrity (#241)
  * The list of known TPM manufacturers has been updated (#242)
* Tue Jan  7 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.4.0
  * An optional `hints` argument has been added to `generate_registration_options()`
    to specify one or more categories of authenticators for the browser to prioritize
    registration of. See `webauthn.helpers.structs.PublicKeyCredentialHint` for more
    information (#234)
* Sat Nov 23 2024 Dirk Müller <dmueller@suse.com>
- update to 2.3.0:
  * The minimum supported version of Python has been bumped up to
    Python 3.9, with ongoing testing from Python 3.9 through
    Python 3.13. Dependencies have been updated as well,
    including upgrading to `cryptography==43.0.3`
* Sat Jun 29 2024 Dirk Müller <dmueller@suse.com>
- update to 2.2.0:
  * All exceptions in `webauthn.helpers.exceptions` now subclass
    the new `webauthn.helpers.exceptions.WebAuthnException` base
    exception
  * Support has been added for the new `"smart-card"` transport
* Fri May 31 2024 Antonio Larrosa <alarrosa@suse.com>
- Initial release of python-webauthn 2.1.0
